@@ -44,6 +44,6 @@ def init():
     for c in clsmembers:
         if issubclass(c[1], Node) and c[1] is not Node:
             cls = c[1]
-            name = cls().id
-            factory = NodeFactory(cls)
+            name = cls().name
+            factory = NodeFactory(cls().cls)
             Runtime.create_node(name, factory)
