@@ -211,7 +211,7 @@ class Spec:
                     properties.append(prop)
 
                 optionVars = Spec.get_option_vars(cls)
-                options = Spec.get_outputs(cls)
+                options = Spec.get_options(cls)
 
                 if len(options) + len(optionVars) > 0:
                     prop = {}
